@@ -131,10 +131,32 @@ void CONFIG::reset_fonts(){ get_confitem()->reset_fonts(); }
 const std::string CONFIG::get_ref_prefix(){ return get_confitem()->ref_prefix + get_confitem()->ref_prefix_space_str; }
 const int CONFIG::ref_prefix_space(){ return get_confitem()->ref_prefix_space; }
 
+// レスにアスキーアートがあると判定する正規表現
+const std::string CONFIG::get_regex_res_aa(){
+    std::string str = get_confitem()->regex_res_aa;
+    int size = str.size();
+
+    // ダブルクオートの削除
+    if( size > 2 && str[ 0 ] == '"' && str[ size - 1 ] == '"' ){
+        str = str.substr( 1, size - 2 );
+    }
+    return str;
+}
+void CONFIG::set_regex_res_aa( const std::string& regex ){
+    get_confitem()->regex_res_aa = "\"" + regex + "\"";
+}
+
 const std::string& CONFIG::get_url_jdhp() { return get_confitem()->url_jdhp; }
 
+// 2chの認証サーバのアドレス
 const std::string& CONFIG::get_url_login2ch() { return get_confitem()->url_login2ch; }
+
+// p2の認証サーバのアドレス
 const std::string& CONFIG::get_url_loginp2() { return get_confitem()->url_loginp2; }
+void CONFIG::set_url_loginp2( const std::string& url ) { get_confitem()->url_loginp2 = url; }
+
+// BEの認証サーバのアドレス
+const std::string& CONFIG::get_url_loginbe() { return get_confitem()->url_loginbe; }
 
 const std::string& CONFIG::get_url_bbsmenu() { return get_confitem()->url_bbsmenu; }
 
@@ -200,6 +222,13 @@ void CONFIG::set_use_ipv6( const bool set ){ get_confitem()->use_ipv6 = set; }
 // 同一ホストに対する最大コネクション数( 1 または 2 )
 const int CONFIG::get_connection_num(){ return get_confitem()->connection_num; }
 
+// 2chのクッキー:HAP
+const bool CONFIG::get_use_cookie_hap(){ return get_confitem()->use_cookie_hap; }
+const std::string& CONFIG::get_cookie_hap(){ return get_confitem()->cookie_hap; }
+const std::string& CONFIG::get_cookie_hap_bbspink(){ return get_confitem()->cookie_hap_bbspink; }
+void CONFIG::set_cookie_hap( const std::string& cookie_hap ){ get_confitem()->cookie_hap = cookie_hap; }
+void CONFIG::set_cookie_hap_bbspink( const std::string& cookie_hap ){ get_confitem()->cookie_hap_bbspink = cookie_hap; }
+
 const std::string& CONFIG::get_command_openurl() { return get_confitem()->command_openurl; }
 void CONFIG::set_command_openurl( const std::string& command ){ get_confitem()->command_openurl = command; }
 
@@ -233,6 +262,9 @@ void CONFIG::set_show_sssp_icon( const bool show ){ get_confitem()->show_ssspico
 const int CONFIG::get_embimg_width(){ return get_confitem()->embimg_width; }
 const int CONFIG::get_embimg_height(){ return get_confitem()->embimg_height; }
 
+// 埋め込み画像ビューを閉じたときにタブも閉じる
+const bool CONFIG::get_hide_imagetab(){ return get_confitem()->hide_imagetab; }
+
 // 画像ビューでdeleteを押したときに確認ダイアログを表示する
 const bool CONFIG::get_show_delimgdiag(){ return get_confitem()->show_delimgdiag; }
 void CONFIG::set_show_delimgdiag( const bool show ){ get_confitem()->show_delimgdiag = show; }
@@ -282,6 +314,13 @@ void CONFIG::set_live_threshode( const int th ){ get_confitem()->live_threshold
 
 const bool CONFIG::get_open_one_category(){ return get_confitem()->open_one_category; }
 const bool CONFIG::get_open_one_favorite(){ return get_confitem()->open_one_favorite; }
+
+// デフォルトの書き込み名
+const std::string CONFIG::get_write_name(){ return get_confitem()->write_name; }
+
+// デフォルトのメールアドレス
+const std::string CONFIG::get_write_mail(){ return get_confitem()->write_mail; }
+
 const bool CONFIG::get_always_write_ok() { return get_confitem()->always_write_ok; }
 void CONFIG::set_always_write_ok( const bool write_ok ){ get_confitem()->always_write_ok = write_ok; }
 
@@ -361,6 +400,11 @@ const bool CONFIG::get_instruct_tglimg(){
 void CONFIG::set_instruct_tglimg( bool tgl ){ get_confitem()->instruct_tglimg = tgl; }
 
 
+// スレビューでdeleteを押したときに確認ダイアログを表示する
+const bool CONFIG::get_show_delartdiag(){ return get_confitem()->show_delartdiag; }
+void CONFIG::set_show_delartdiag( const bool show ){ get_confitem()->show_delartdiag = show; }
+
+
 const double CONFIG::get_adjust_underline_pos(){ return get_confitem()->adjust_underline_pos; }
 void CONFIG::set_adjust_underline_pos( const double pos ){ get_confitem()->adjust_underline_pos = pos; }
 
@@ -389,6 +433,16 @@ const bool CONFIG::get_reload_allthreads(){ return get_confitem()->reload_allthr
 const int CONFIG::get_tab_min_str(){ return get_confitem()->tab_min_str; }
 
 const bool CONFIG::get_show_tab_icon(){ return get_confitem()->show_tab_icon; }
+
+// タブ上でマウスホイールを回転してタブを切り替える
+const bool CONFIG::get_switchtab_wheel(){ return get_confitem()->switchtab_wheel; }
+
+// ビュー内から他のビューを開いたときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
+const int CONFIG::get_newtab_pos(){  return get_confitem()->newtab_pos; }
+
+// 次スレ検索を開くときのタブの位置 ( 0: 次スレ検索タブ 1:新しいタブ 2:アクティブなタブを置き換え )
+const int CONFIG::get_boardnexttab_pos(){  return get_confitem()->boardnexttab_pos; }
+
 const bool CONFIG::get_show_post_mark(){ return get_confitem()->show_post_mark; }
 void CONFIG::set_show_post_mark( const bool show ){ get_confitem()->show_post_mark = show; }
 
@@ -455,11 +509,22 @@ void CONFIG::set_list_abone_regex( const std::list< std::string >& regex )
     get_confitem()->list_abone_regex = MISC::remove_nullline_from_list( get_confitem()->list_abone_regex );
 }
 
+
+// デフォルトで透明、連鎖あぼーんをするか
 const bool CONFIG::get_abone_transparent(){ return get_confitem()->abone_transparent; }
 void CONFIG::set_abone_transparent( const bool set ){ get_confitem()->abone_transparent = set; }
+
 const bool CONFIG::get_abone_chain(){ return get_confitem()->abone_chain; }
 void CONFIG::set_abone_chain( const bool set ){ get_confitem()->abone_chain = set; }
 
+// NG正規表現によるあぼーん時に大小と全半角文字の違いを無視
+const bool CONFIG::get_abone_icase(){ return get_confitem()->abone_icase; }
+void CONFIG::set_abone_icase( const bool set ){ get_confitem()->abone_icase = set; }
+
+const bool CONFIG::get_abone_wchar(){ return get_confitem()->abone_wchar; }
+void CONFIG::set_abone_wchar( const bool set ){ get_confitem()->abone_wchar = set; }
+
+
 const bool CONFIG::get_expand_sidebar(){ return get_confitem()->expand_sidebar; }
 
 const bool CONFIG::get_expand_rpane(){ return get_confitem()->expand_rpane; }
@@ -501,6 +566,8 @@ const bool CONFIG::get_disable_close(){ return get_confitem()->disable_close; }
 const bool CONFIG::get_show_hide_menubar_diag(){ return get_confitem()->show_hide_menubar_diag; }
 void CONFIG::set_show_hide_menubar_diag( const bool set ){ get_confitem()->show_hide_menubar_diag = set; }
 
+// 状態変更時にメインステータスバーの色を変える
+const bool CONFIG::get_change_stastatus_color(){ return get_confitem()->change_stastatus_color; }
 
 // まちBBSの取得に offlaw.cgi を使用する
 const bool CONFIG::get_use_machi_offlaw(){ return get_confitem()->use_machi_offlaw; }
