@@ -97,6 +97,7 @@ namespace CONTROL
 
         Quit,
         Save,
+        SaveDat,            // alias: Save
         Delete,
         Reload,
         ReloadArticle,
@@ -106,15 +107,20 @@ namespace CONTROL
         Copy,
         SelectAll,
         AppendFavorite,
-        Property,
         Lock,
-    
+
+        PreferenceView,
+        PreferenceBoard,    // alias: PreferenceView
+        PreferenceArticle,  // alias: PreferenceView
+        PreferenceImage,    // alias: PreferenceView
+
         Search,
         CloseSearchBar,
         HiLightOff,
         SearchInvert,
         SearchNext,
         SearchPrev,
+        SearchTitle,
         DrawOutAnd,
         DrawOutOr,
 
@@ -124,6 +130,7 @@ namespace CONTROL
         QuitJD,
         MaximizeMainWin,
         IconifyMainWin,
+        FullScreen,
 
         ClickButton, // 以下、マウスボタン専用の設定
         DblClickButton,
@@ -188,10 +195,14 @@ namespace CONTROL
 
         SearchNextArticle,
         SearchWeb,
-        SearchTitle,
         SearchCacheLocal,
         SearchCacheAll,
 
+        ShowSelectImage,
+        DeleteSelectImage,
+        AboneSelectImage,
+        AboneSelectionRes,
+
         PopupWarpButton, // 以下、マウスボタン専用の設定
         ReferResButton, 
         BmResButton,
